@@ -163,10 +163,12 @@
   "base-uri 'none'; "                        \
   "connect-src 'self'; "                     \
   "script-src 'self'; "                      \
+  "script-src-elem 'self' 'unsafe-inline';"  \
   "frame-ancestors 'none'; "                 \
   "form-action 'self'; "                     \
   "style-src-elem 'self' 'unsafe-inline'; "  \
   "style-src 'self' 'unsafe-inline'; "       \
+  "font-src 'self';"                         \
   "img-src 'self' blob:;"
 
 /**
@@ -348,6 +350,10 @@ params_append_mhd (params_t *params, const char *name, const char *filename,
       || (strncmp (name, "file:", strlen ("file:")) == 0)
       || (strncmp (name, "include_id_list:", strlen ("include_id_list:")) == 0)
       || (strncmp (name, "parameter:", strlen ("parameter:")) == 0)
+      || (strncmp (name, "param:", strlen ("param:")) == 0)
+      || (strncmp (name,
+                   "param_using_default:", strlen ("param_using_default:"))
+          == 0)
       || (strncmp (name, "password:", strlen ("password:")) == 0)
       || (strncmp (name, "preference:", strlen ("preference:")) == 0)
       || (strncmp (name, "select:", strlen ("select:")) == 0)
@@ -822,6 +828,7 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (create_port_list)
   ELSE (create_port_range)
   ELSE (create_report)
+  ELSE (create_report_config)
   ELSE (create_scanner)
   ELSE (create_schedule)
   ELSE (create_task)
@@ -844,6 +851,7 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (delete_port_list)
   ELSE (delete_port_range)
   ELSE (delete_report)
+  ELSE (delete_report_config)
   ELSE (delete_report_format)
   ELSE (delete_role)
   ELSE (delete_scanner)
@@ -884,6 +892,7 @@ exec_gmp_post (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (save_override)
   ELSE (save_permission)
   ELSE (save_port_list)
+  ELSE (save_report_config)
   ELSE (save_report_format)
   ELSE (save_role)
   ELSE (save_scanner)
@@ -1487,6 +1496,8 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (export_port_list)
   ELSE (export_port_lists)
   ELSE (export_preference_file)
+  ELSE (export_report_config)
+  ELSE (export_report_configs)
   ELSE (export_report_format)
   ELSE (export_report_formats)
   ELSE (export_result)
@@ -1569,6 +1580,8 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (get_port_lists)
   ELSE (get_report)
   ELSE (get_reports)
+  ELSE (get_report_config)
+  ELSE (get_report_configs)
   ELSE (get_report_format)
   ELSE (get_report_formats)
   ELSE (get_resource_names)
@@ -1594,7 +1607,24 @@ exec_gmp_get (http_connection_t *con, gsad_connection_info_t *con_info,
   ELSE (get_tickets)
   ELSE (get_tls_certificate)
   ELSE (get_tls_certificates)
-  ELSE (get_trash)
+  ELSE (get_trash_alerts)
+  ELSE (get_trash_configs)
+  ELSE (get_trash_credentials)
+  ELSE (get_trash_filters)
+  ELSE (get_trash_groups)
+  ELSE (get_trash_notes)
+  ELSE (get_trash_overrides)
+  ELSE (get_trash_permissions)
+  ELSE (get_trash_port_lists)
+  ELSE (get_trash_report_configs)
+  ELSE (get_trash_report_formats)
+  ELSE (get_trash_roles)
+  ELSE (get_trash_scanners)
+  ELSE (get_trash_schedules)
+  ELSE (get_trash_tags)
+  ELSE (get_trash_targets)
+  ELSE (get_trash_tasks)
+  ELSE (get_trash_tickets)
   ELSE (get_user)
   ELSE (get_users)
   ELSE (get_vulns)
